aboutsummaryrefslogtreecommitdiffstats
path: root/include/disp.h
diff options
context:
space:
mode:
authorJoerie de Gram <j.de.gram@gmail.com>2011-08-17 15:57:47 +0200
committerJoerie de Gram <j.de.gram@gmail.com>2011-08-17 15:57:47 +0200
commitd3bd80a932e4f76b6cae280c78f118882f3b176d (patch)
treecad99877da53cad9fae5907fd43fe5a79e50ad37 /include/disp.h
parenta3c46bd32430db57b97a1498d3da9a2c01df22ad (diff)
downloadhardware_replicant_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.tar.gz
hardware_replicant_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.tar.bz2
hardware_replicant_libsamsung-ipc-d3bd80a932e4f76b6cae280c78f118882f3b176d.zip
Rename library to libsamsung-ipc
Diffstat (limited to 'include/disp.h')
-rw-r--r--include/disp.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/include/disp.h b/include/disp.h
index 8b14d5c..aa6c6cf 100644
--- a/include/disp.h
+++ b/include/disp.h
@@ -1,30 +1,30 @@
/**
* This file is part of libmsm-h1.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
* libmsm-h1 is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* libmsm-h1 is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with libmsm-h1. If not, see <http://www.gnu.org/licenses/>.
+ * along with libsamsung-ipc. If not, see <http://www.gnu.org/licenses/>.
*
*/
#ifndef __DISP_H__
#define __DISP_H__
-#define MSM_DISP_ICON_INFO 0x0701
-#define MSM_DISP_HOMEZONE_INFO 0x0702
+#define IPC_DISP_ICON_INFO 0x0701
+#define IPC_DISP_HOMEZONE_INFO 0x0702
-struct msm_disp_icon_info {
+struct ipc_disp_icon_info {
unsigned char unk, rssi, battery, act, reg;
} __attribute__((__packed__));
@@ -1,30 +1,30 @@
/**
- * This file is part of libmsm-h1.
+ * This file is part of libsamsung-ipc.
*
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
@@ -1,30 +1,30 @@
* Copyright (C) 2010-2011 Joerie de Gram <j.de.gram@gmail.com>
*
- * libmsm-h1 is free software: you can redistribute it and/or modify
+ * libsamsung-ipc is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -1,30 +1,30 @@
* (at your option) any later version.
*
- * libmsm-h1 is distributed in the hope that it will be useful,
+ * libsamsung-ipc is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the